@@ -328,9 +328,11 @@ class PromptManager:
                                               prompt_as_previous=prompt_as_previous)
         max_tokens = chunk_token_distribution_data['completion']['available']
         self.prompt ={"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt }],"max_tokens": max_tokens}
+        blank = True
         for key in self.key_check:
             if key not in ['instructions']:
-                break
+                blank=False
+        if blank:
             self.prompt['blank_prompt']=True
         return self.prompt
 
