@@ -91,6 +91,7 @@ class ResponseManager:
         self.model_mgr=self.prompt_mgr.model_mgr
         self.api_mgr=api_mgr
         self.title=title
+        self.save_manager = SaveManager()
         self.directory=mkdirs(directory or os.path.join(os.getcwd(),'response_data'))
         self.chunk_token_distributions=prompt_mgr.chunk_token_distributions
         self.output=[]
@@ -156,12 +157,12 @@ class ResponseManager:
         """
         return self.query_js
     def get_abort(self):
-       self.abort_js = {"abort":None,"additional_responses":None,"request_chunks":None}
+       self.abort_js = {"abort":None,"additional_responses":None,"request_chunks":None,"blank_prompt":self.prompt.get('blank_prompt')}
        for key,value in self.prompt_mgr.instruction_mgr.instructions_js.items():
            if key in list(self.abort_js.keys()):
               setattr(self,key,value)
               self.abort_js[key]=value
-           if self.abort_js["abort"]:
+           if self.abort_js["abort"] or self.abort_js["blank_prompt"]:
                return True
        if self.abort_js["request_chunks"] or self.abort_js["additional_responses"]:
            return False
@@ -213,6 +214,7 @@ class ResponseManager:
         self.total_dists = 0
         for dist in self.chunk_token_distributions:
             self.total_dists +=len(dist)
+        input(self.chunk_token_distributions)
         for chunk_token_distribution_number,distributions in enumerate(self.chunk_token_distributions):
             for chunk_number,distribution in enumerate(distributions):
                 self.chunk_token_distribution_number=chunk_token_distribution_number
@@ -222,7 +224,7 @@ class ResponseManager:
                 abort_it=False
                 while response_loop:
                     self.send_query()
-                    if self.get_abort() or self.abort_js["abort"] or self.prompt.get('blank_prompt'):
+                    if self.get_abort() or self.abort_js["abort"]:
                         response_loop=False
                         break
                 print(f'in while {self.i_query}')
