@@ -886,6 +886,7 @@ class GptManager:
                 self.updated_progress = True
         if not self.test_bool:
             self.latest_output=self.thread_mgr.get_last_result(self.api_call_list[-1])
+        self.latest_output=self.latest_output or []
         self.output_list.append(self.latest_output)
   
         self.update_progress_chunks(done=True)
@@ -998,7 +999,10 @@ class GptManager:
         """
         Initializes the display of the latest output in the GUI.
         """
-        self.current_output=self.latest_output[-1]
+        if len(self.latest_output)>0:
+            self.current_output=self.latest_output[-1]
+        else:
+            self.current_output=[]
         self.response_text_number_actual=0
         self.response_text_number_display=1
         self.window_mgr.update_value(key='-RESPONSE_TEXT_NUMBER-',value=self.response_text_number_display)
@@ -1107,17 +1111,18 @@ class GptManager:
 
         This function is often called after a new API response has been received and saved.
         """
-        for data in self.latest_output:
-            file_path = get_any_value(data,'file_path')
+        if self.latest_output:
+            for data in self.latest_output:
+                file_path = get_any_value(data,'file_path')
+                if file_path in self.new_response_path_list:
+                    self.new_response_path_list.remove(file_path)
+                self.new_response_path_list.append(file_path)
+            files_list = self.window['-FILES_LIST_RESPONSES-'].Values
             if file_path in self.new_response_path_list:
-                self.new_response_path_list.remove(file_path)
-            self.new_response_path_list.append(file_path)
-        files_list = self.window['-FILES_LIST_RESPONSES-'].Values
-        if file_path in self.new_response_path_list:
-            if file_path in files_list:
-                files_list.remove(file_path)
-        files_list=self.new_response_path_list+files_list
-        self.window_mgr.update_value('-FILES_LIST_RESPONSES-',args={"values":files_list})
+                if file_path in files_list:
+                    files_list.remove(file_path)
+            files_list=self.new_response_path_list+files_list
+            self.window_mgr.update_value('-FILES_LIST_RESPONSES-',args={"values":files_list})
 
     def aggregate_conversations(self,directory:str=None):
         """
